Crate kcr_pxc_percona_com

Crate kcr_pxc_percona_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the pxc.percona.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

pxc.percona.com/v1

  • PerconaXtraDBClusterBackup
  • PerconaXtraDBClusterRestore
  • PerconaXtraDBCluster

Modules

v1